@@ -6,6 +6,7 @@ import json
 import os
 import shutil
 import sys
+import tempfile
 from dataclasses import dataclass
 from io import BytesIO, StringIO
 from pathlib import Path
@@ -22,8 +23,10 @@ from pdm.cli.actions import do_init
 from pdm.cli.hooks import HookManager
 from pdm.core import Core
 from pdm.exceptions import CandidateInfoNotFound
+from pdm.installers.installers import install_wheel
+from pdm.models.backends import get_backend
 from pdm.models.candidates import Candidate
-from pdm.models.environment import Environment
+from pdm.models.environment import Environment, PrefixEnvironment
 from pdm.models.repositories import BaseRepository
 from pdm.models.requirements import (
     Requirement,
@@ -117,6 +120,14 @@ class TestRepository(BaseRepository):
         self._pypi_data = {}
         self.load_fixtures()
 
+    def get_raw_dependencies(self, candidate):
+        try:
+            pypi_data = self._pypi_data[candidate.req.key][candidate.version]
+        except KeyError:
+            return candidate.prepare(self.environment).metadata.requires or []
+        else:
+            return pypi_data.get("dependencies", [])
+
     def add_candidate(self, name, version, requires_python=""):
         pypi_data = self._pypi_data.setdefault(normalize_name(name), {}).setdefault(
             version, {}
@@ -170,14 +181,45 @@ class TestRepository(BaseRepository):
         self._pypi_data = json.loads(json_file.read_text())
 
 
+@pytest.fixture(scope="session")
+def build_env():
+    with tempfile.TemporaryDirectory("-env", prefix="pdm-test-") as d:
+        p = Core().create_project(d)
+        env = PrefixEnvironment(p, d)
+        for wheel_name in (
+            "pdm_pep517-1.0.0-py3-none-any.whl",
+            "poetry_core-1.3.2-py3-none-any.whl",
+            "setuptools-65.4.1-py3-none-any.whl",
+            "wheel-0.37.1-py2.py3-none-any.whl",
+            "flit_core-3.6.0-py3-none-any.whl",
+        ):
+            wheel = FIXTURES / "artifacts" / wheel_name
+            install_wheel(str(wheel), env)
+        yield d
+
+
+class Metadata(dict):
+    def get_all(self, name, fallback=None):
+        return [self[name]] if name in self else fallback
+
+    def __getitem__(self, __key):
+        return dict.get(self, __key)
+
+
 class Distribution:
-    def __init__(self, key, version, editable=False):
+    def __init__(self, key, version, editable=False, metadata=None):
         self.version = version
         self.link_file = "editable" if editable else None
         self.dependencies = []
-        self.metadata = {"Name": key}
+        self._metadata = {"Name": key, "Version": version}
+        if metadata:
+            self._metadata.update(metadata)
         self.name = key
 
+    @property
+    def metadata(self):
+        return Metadata(self._metadata)
+
     def as_req(self):
         return parse_requirement(f"{self.name}=={self.version}")
 
@@ -219,10 +261,9 @@ def working_set(mocker, repository):
     mocker.patch.object(Environment, "get_working_set", return_value=rv)
 
     def install(candidate):
-        dependencies = repository.get_dependencies(candidate)[0]
         key = normalize_name(candidate.name)
         dist = Distribution(key, candidate.version, candidate.req.editable)
-        dist.dependencies = [dep.as_line() for dep in dependencies]
+        dist.dependencies = repository.get_raw_dependencies(candidate)
         rv.add_distribution(dist)
 
     def uninstall(dist):
@@ -272,7 +313,7 @@ def index():
 
 
 @pytest.fixture()
-def project_no_init(tmp_path, mocker, core, index, monkeypatch):
+def project_no_init(tmp_path, mocker, core, index, monkeypatch, build_env):
     test_home = tmp_path / ".pdm-home"
     test_home.mkdir(parents=True)
     test_home.joinpath("config.toml").write_text(
@@ -288,6 +329,7 @@ def project_no_init(tmp_path, mocker, core, index, monkeypatch):
         "pdm.models.environment.PDMSession",
         functools.partial(get_pypi_session, overrides=index),
     )
+    mocker.patch("pdm.builders.base.EnvBuilder.get_shared_env", return_value=build_env)
     tmp_path.joinpath("caches").mkdir(parents=True)
     p.global_config["cache_dir"] = tmp_path.joinpath("caches").as_posix()
     p.project_config["python.path"] = find_python_in_path(sys.base_prefix).as_posix()
@@ -303,11 +345,9 @@ def project_no_init(tmp_path, mocker, core, index, monkeypatch):
 
 
 @pytest.fixture()
-def local_finder(project_no_init, mocker):
+def local_finder(project_no_init):
     artifacts_dir = str(FIXTURES / "artifacts")
-    return_value = ["--no-index", "--find-links", artifacts_dir]
-    mocker.patch("pdm.builders.base.prepare_pip_source_args", return_value=return_value)
-    project_no_init.tool_settings["source"] = [
+    project_no_init.pyproject.settings["source"] = [
         {
             "type": "find_links",
             "verify_ssl": False,
@@ -315,13 +355,19 @@ def local_finder(project_no_init, mocker):
             "name": "pypi",
         }
     ]
-    project_no_init.write_pyproject()
+    project_no_init.pyproject.write()
 
 
 @pytest.fixture()
 def project(project_no_init):
     hooks = HookManager(project_no_init, ["post_init"])
-    do_init(project_no_init, "test_project", "0.0.0", hooks=hooks)
+    do_init(
+        project_no_init,
+        "test_project",
+        "0.0.0",
+        hooks=hooks,
+        build_backend=get_backend("pdm-pep517"),
+    )
     # Clean the cached property
     project_no_init._environment = None
     return project_no_init
@@ -344,7 +390,7 @@ def fixture_project(project_no_init):
     def func(project_name):
         source = FIXTURES / "projects" / project_name
         copytree(source, project_no_init.root)
-        project_no_init._pyproject = None
+        project_no_init.pyproject.reload()
         return project_no_init
 
     return func
@@ -437,11 +483,12 @@ def invoke(core, monkeypatch):
     return caller
 
 
-BACKENDS = ["virtualenv", "venv"]
+VENV_BACKENDS = ["virtualenv", "venv"]
 
 
-@pytest.fixture(params=BACKENDS)
+@pytest.fixture(params=VENV_BACKENDS)
 def venv_backends(project, request):
     project.project_config["venv.backend"] = request.param
+    project.project_config["venv.prompt"] = "{project_name}-{python_version}"
     project.project_config["python.use_venv"] = True
     shutil.rmtree(project.root / "__pypackages__", ignore_errors=True)
