@@ -51,10 +51,6 @@ REQUIREMENTS = [
         "git+git@github.com:pypa/pip.git#egg=pip",
         "pip @ git+ssh://git@github.com/pypa/pip.git",
     ),
-    (
-        "./tests/fixtures/projects/demo",
-        "demo @ file:///${PROJECT_ROOT}/tests/fixtures/projects/demo",
-    ),
 ]
 
 
@@ -69,7 +65,6 @@ def test_convert_req_dict_to_req_line(req, result):
     "line,expected",
     [
         ("requests; os_name=>'nt'", "Invalid marker:"),
-        ("./nonexist", r"The local path (.+)? does not exist"),
         ("./tests", r"The local path (.+)? is not installable"),
     ],
 )
